@@ -1,7 +1,7 @@
 package Perinci::Examples::Stream;
 
-our $DATE = '2016-01-20'; # DATE
-our $VERSION = '0.65'; # VERSION
+our $DATE = '2016-01-22'; # DATE
+our $VERSION = '0.66'; # VERSION
 
 use 5.010;
 use strict;
@@ -44,6 +44,61 @@ sub nat {
      }];
 }
 
+$SPEC{word} = {
+    v => 1.1,
+    summary => 'This function produces a stream of random words',
+    args => {
+        num => {
+            summary => 'Limit number of words to produce',
+            schema => 'int*',
+            cmdline_aliases => {n=>{}},
+        },
+    },
+    result => {
+        stream => 1,
+        schema => ['str*', match=>'\A\w+\z'],
+    },
+};
+sub word {
+    my %args = @_;
+    my $i = 1;
+    my $num = $args{num};
+    [200, "OK", sub {
+         return undef if defined($num) && $i > $num;
+         $i++;
+         join('', map { ['a'..'z']->[26*rand()] } 1..(int(6*rand)+5));
+     }];
+}
+
+$SPEC{word_err} = {
+    v => 1.1,
+    summary => 'Like word(), but 1 in every 10 words will be a non-word (which fails result schema)',
+    args => {
+        num => {
+            summary => 'Limit number of words to produce',
+            schema => 'int*',
+            cmdline_aliases => {n=>{}},
+        },
+    },
+    result => {
+        stream => 1,
+        schema => ['str*', match=>'\A\w+\z'],
+    },
+};
+sub word_err {
+    my %args = @_;
+    my $i = 1;
+    my $num = $args{num};
+    [200, "OK", sub {
+         return undef if defined($num) && $i > $num;
+         if ($i++ % 10 == 0) {
+             "contain space";
+         } else {
+             join('', map { ['a'..'z']->[26*rand()] } 1..(int(6*rand)+5));
+         }
+     }];
+}
+
 $SPEC{hash_stream} = {
     v => 1.1,
     summary => 'This function produces a stream of hashes',
@@ -234,7 +289,7 @@ Perinci::Examples::Stream - Examples for streaming input/output
 
 =head1 VERSION
 
-This document describes version 0.65 of Perinci::Examples::Stream (from Perl distribution Perinci-Examples), released on 2016-01-20.
+This document describes version 0.66 of Perinci::Examples::Stream (from Perl distribution Perinci-Examples), released on 2016-01-22.
 
 =head1 DESCRIPTION
 
@@ -456,13 +511,69 @@ that contains extra information.
 
 Return value:  (hash)
 
+
+=head2 word(%args) -> [status, msg, result, meta]
+
+This function produces a stream of random words.
+
+This function is not exportable.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<num> => I<int>
+
+Limit number of words to produce.
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (str)
+
+
+=head2 word_err(%args) -> [status, msg, result, meta]
+
+Like word(), but 1 in every 10 words will be a non-word (which fails result schema).
+
+This function is not exportable.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<num> => I<int>
+
+Limit number of words to produce.
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (str)
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Examples>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Perinci-Examples>.
+Source repository is at L<https://github.com/sharyanto/perl-Perinci-Examples>.
 
 =head1 BUGS
 
